@@ -24,10 +24,12 @@ class FakePreseemModel:
     _sites = {}  # company_uuid to {site_uuid to Site object}
     _elem_disc = {}  # company_uuid to {uuid to ElementDiscovery object}
 
-    def _new_attrs():
-        """Generate attributes for a new preseem-model object."""
+    def _new_attrs(uuid=None):
+        """Generate attributes for a new preseem-model object.
+           By default this generates a random UUID, or a UUID can be passed in."""
         now = time.time()
-        uuid = uuid4()
+        if not uuid:
+            uuid = uuid4()
         return {
             'id': uuid.int & (1 << 64) - 1,
             'uuid': uuid.bytes,
@@ -41,6 +43,15 @@ class FakePreseemModel:
         obj.inactive = True
         obj.updated_at = obj.inactive_time = time.time()
 
+    def clear(self):
+        FakePreseemModel._companies.clear()
+        FakePreseemModel._elements.clear()
+        FakePreseemModel._accounts.clear()
+        FakePreseemModel._packages.clear()
+        FakePreseemModel._services.clear()
+        FakePreseemModel._sites.clear()
+        FakePreseemModel._elem_disc.clear()
+
     async def init(self):
         pass
 
@@ -89,7 +100,7 @@ class FakePreseemModel:
 
         @classmethod
         async def Create(cls, **kwargs):
-            obj = cls(**FakePreseemModel._new_attrs(),
+            obj = cls(**FakePreseemModel._new_attrs(kwargs.get('uuid')),
                       name=kwargs.get('name') or '',
                       parent_uuid=kwargs.get('parent_uuid'),
                       old_id=kwargs.get('old_id'))
