@@ -620,6 +620,7 @@ class BaseNetworkElement(Errorable):
         "_site_uuid",
         "_uuid",
         "_site_id",
+        "_poller_hash",
     ]
     # this is just used to list fields we want to print with __repr__
     attrs = ('id', 'name', 'site', 'host', 'community', 'url')
@@ -637,6 +638,7 @@ class BaseNetworkElement(Errorable):
         self._site_uuid = None  # used by sync_preseem_model for resolution
         self._uuid = None  # used to pass uuid back from sync_preseem_model
         self._site_id = None  # used for old topology mapping to a site
+        self._poller_hash = None  # used for explicit element creation
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -720,6 +722,26 @@ class BaseNetworkElement(Errorable):
         if self._check_str('site_id', value):
             self._site_id = value if value is not None else None
 
+    @property
+    def poller_hash(self):
+        return self._poller_hash
+
+    @poller_hash.setter
+    def poller_hash(self, value):
+        if value is not None:
+            if not isinstance(value, bytes):
+                self.err(
+                    'poller_hash', value,
+                    TypeError(
+                        f"The {self.typename} 'poller_hash' must be of type bytes."))
+                return
+            if len(value) != 32:
+                self.err(
+                    'poller_hash', value,
+                    ValueError(f"The {self.typename} 'poller_hash' must be 32 bytes."))
+                return
+        self._poller_hash = value if value is not None else None
+
     def __repr__(self):
         attr_values = [(attr, getattr(self, attr)) for attr in self.attrs]
         attributes_str = ', '.join(f"{attr}={value!r}" for attr, value in attr_values)
