@@ -1,9 +1,10 @@
 import os
+from typing import Dict
 import yaml
 import logging
 
 
-def load_vendor_map() -> dict[str, str]:
+def load_vendor_map() -> Dict[str, str]:
     """
     Load the YAML input file for the vendor code mapped to the vendor.
     """
@@ -17,12 +18,9 @@ def load_vendor_map() -> dict[str, str]:
             return yaml.safe_load(f) or {}
     except FileNotFoundError:
         logging.error(f"Vendor map file not found: {path}")
-        return {}
     except yaml.YAMLError as e:
         logging.error(f"Invalid YAML format in vendor map: {e}")
-        return {}
     except Exception as e:
         logging.error(f"Error loading vendor map: {e}")
-        return {}
 
-    return ont_vendor_map
+    return {}
